@@ -89,9 +89,6 @@ try to unroll inner for(x=0 ... loop to avoid these damn if(x ... checks
 #include "postprocess_internal.h"
 #include "libavutil/avstring.h"
 
-#include "libavutil/ffversion.h"
-const char postproc_ffversion[] = "FFmpeg version " FFMPEG_VERSION;
-
 unsigned postproc_version(void)
 {
     av_assert0(LIBPOSTPROC_VERSION_MICRO >= 100);
@@ -157,7 +154,7 @@ static const struct PPFilter filters[]=
     {NULL, NULL,0,0,0,0} //End Marker
 };
 
-static const char *replaceTable[]=
+static const char * const replaceTable[]=
 {
     "default",      "hb:a,vb:a,dr:a",
     "de",           "hb:a,vb:a,dr:a",
@@ -321,13 +318,13 @@ static inline void doHorizDefFilter_C(uint8_t dst[], int stride, const PPContext
 
             if(q>0)
             {
-                d= d<0 ? 0 : d;
-                d= d>q ? q : d;
+                d = FFMAX(d, 0);
+                d = FFMIN(d, q);
             }
             else
             {
-                d= d>0 ? 0 : d;
-                d= d<q ? q : d;
+                d = FFMIN(d, 0);
+                d = FFMAX(d, q);
             }
 
             dst[3]-= d;
@@ -518,11 +515,11 @@ static av_always_inline void do_a_deblock_C(uint8_t *src, int step,
                 d*= FFSIGN(-middleEnergy);
 
                 if(q>0){
-                    d= d<0 ? 0 : d;
-                    d= d>q ? q : d;
+                    d = FFMAX(d, 0);
+                    d = FFMIN(d, q);
                 }else{
-                    d= d>0 ? 0 : d;
-                    d= d<q ? q : d;
+                    d = FFMIN(d, 0);
+                    d = FFMAX(d, q);
                 }
 
                 src[3*step]-= d;
@@ -719,10 +716,10 @@ pp_mode *pp_get_mode_by_name_and_quality(const char *name, int quality)
         int enable=1; //does the user want us to enabled or disabled the filter
 
         filterToken= strtok(p, filterDelimiters);
-        if(filterToken == NULL) break;
+        if(!filterToken) break;
         p+= strlen(filterToken) + 1; // p points to next filterToken
         filterName= strtok(filterToken, optionDelimiters);
-        if (filterName == NULL) {
+        if (!filterName) {
             ppMode->error++;
             break;
         }
@@ -735,7 +732,7 @@ pp_mode *pp_get_mode_by_name_and_quality(const char *name, int quality)
 
         for(;;){ //for all options
             option= strtok(NULL, optionDelimiters);
-            if(option == NULL) break;
+            if(!option) break;
 
             av_log(NULL, AV_LOG_DEBUG, "pp: option: %s\n", option);
             if(!strcmp("autoq", option) || !strcmp("a", option)) q= quality;
@@ -751,7 +748,7 @@ pp_mode *pp_get_mode_by_name_and_quality(const char *name, int quality)
         options[numOfUnknownOptions] = NULL;
 
         /* replace stuff from the replace Table */
-        for(i=0; replaceTable[2*i]!=NULL; i++){
+        for(i=0; replaceTable[2*i]; i++){
             if(!strcmp(replaceTable[2*i], filterName)){
                 int newlen= strlen(replaceTable[2*i + 1]);
                 int plen;
@@ -771,7 +768,7 @@ pp_mode *pp_get_mode_by_name_and_quality(const char *name, int quality)
             }
         }
 
-        for(i=0; filters[i].shortName!=NULL; i++){
+        for(i=0; filters[i].shortName; i++){
             if(   !strcmp(filters[i].longName, filterName)
                || !strcmp(filters[i].shortName, filterName)){
                 ppMode->lumMode &= ~filters[i].mask;
@@ -790,7 +787,7 @@ pp_mode *pp_get_mode_by_name_and_quality(const char *name, int quality)
                     int o;
                     ppMode->minAllowedY= 16;
                     ppMode->maxAllowedY= 234;
-                    for(o=0; options[o]!=NULL; o++){
+                    for(o=0; options[o]; o++){
                         if(  !strcmp(options[o],"fullyrange")
                            ||!strcmp(options[o],"f")){
                             ppMode->minAllowedY= 0;
@@ -804,7 +801,7 @@ pp_mode *pp_get_mode_by_name_and_quality(const char *name, int quality)
                     int o;
                     int numOfNoises=0;
 
-                    for(o=0; options[o]!=NULL; o++){
+                    for(o=0; options[o]; o++){
                         char *tail;
                         ppMode->maxTmpNoise[numOfNoises]=
                             strtol(options[o], &tail, 0);
@@ -819,7 +816,7 @@ pp_mode *pp_get_mode_by_name_and_quality(const char *name, int quality)
                      || filters[i].mask == V_A_DEBLOCK || filters[i].mask == H_A_DEBLOCK){
                     int o;
 
-                    for(o=0; options[o]!=NULL && o<2; o++){
+                    for(o=0; options[o] && o<2; o++){
                         char *tail;
                         int val= strtol(options[o], &tail, 0);
                         if(tail==options[o]) break;
@@ -833,7 +830,7 @@ pp_mode *pp_get_mode_by_name_and_quality(const char *name, int quality)
                     int o;
                     ppMode->forcedQuant= 15;
 
-                    for(o=0; options[o]!=NULL && o<1; o++){
+                    for(o=0; options[o] && o<1; o++){
                         char *tail;
                         int val= strtol(options[o], &tail, 0);
                         if(tail==options[o]) break;
@@ -970,7 +967,7 @@ void  pp_postprocess(const uint8_t * src[3], const int srcStride[3],
                        FFMAX(minStride, c->stride),
                        FFMAX(c->qpStride, absQPStride));
 
-    if(QP_store==NULL || (mode->lumMode & FORCE_QUANT)){
+    if(!QP_store || (mode->lumMode & FORCE_QUANT)){
         int i;
         QP_store= c->forcedQPTable;
         absQPStride = QPStride = 0;
